@@ -33,7 +33,7 @@ class Scaler:
         self._fitted = True
         return self
 
-    def transform(self, X, return_vector=True):
+    def transform(self, X, return_vector=False):
         """
         :type X: DataFrame
         :type return_vector: bool
